@@ -1,6 +1,6 @@
 
 plot.immer_HRM <- function( x , ... ){
 	class(x) <- "mcmc.sirt"
-	plot( x , ... )
+	graphics::plot( x , ... )
 		}
 	
